@@ -160,7 +160,15 @@ class Client:
         )
         return _json_decode(response)
 
-    def create_app_client(self, generate_secret=True, logout_urls=None, callback_urls=None, **optional_args) -> Dict:
+    def create_app_client(
+        self,
+        generate_secret=True,
+        logout_urls=None,
+        callback_urls=None,
+        login_urls=None,
+        default_login_url=None,
+        **optional_args
+    ) -> Dict:
         """Creates an appClient, calls the POST /appClients endpoint.
 
         >>> from las.client import Client
@@ -177,6 +185,10 @@ class Client:
         :type logout_urls: List[str]
         :param callback_urls: List of callback urls
         :type callback_urls: List[str]
+        :param login_urls: List of login urls
+        :type login_urls: List[str]
+        :param default_login_url: Default login url
+        :type default_login_url: str
         :return: AppClient response from REST API
         :rtype: dict
 
@@ -186,6 +198,8 @@ class Client:
         body = dictstrip({
             'logoutUrls': logout_urls,
             'callbackUrls': callback_urls,
+            'loginUrls': login_urls,
+            'defaultLoginUrl': default_login_url,
             **optional_args,
         })
         body['generateSecret'] = generate_secret
@@ -214,6 +228,23 @@ class Client:
         }
         return self._make_request(requests.get, '/appClients', params=params)
 
+    def update_app_client(self, app_client_id, **optional_args) -> Dict:
+        """Updates an appClient, calls the PATCH /appClients/{appClientId} endpoint.
+
+        :param app_client_id: Id of the appClient
+        :type app_client_id: str
+        :param name: Name of the appClient
+        :type name: Optional[str]
+        :param description: Description of the appClient
+        :type description: Optional[str]
+        :return: AppClient response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.patch, f'/appClients/{app_client_id}', body=optional_args)
+
     def delete_app_client(self, app_client_id: str) -> Dict:
         """Delete the appClient with the provided appClientId, calls the DELETE /appClients/{appClientId} endpoint.
 
@@ -382,6 +413,23 @@ class Client:
         }
         return self._make_request(requests.get, '/batches', params=params)
 
+    def update_batch(self, batch_id, **optional_args) -> Dict:
+        """Updates a batch, calls the PATCH /batches/{batchId} endpoint.
+
+        :param batch_id: Id of the batch
+        :type batch_id: str
+        :param name: Name of the batch
+        :type name: Optional[str]
+        :param description: Description of the batch
+        :type description: Optional[str]
+        :return: Batch response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.patch, f'/batches/{batch_id}', body=optional_args)
+
     def delete_batch(self, batch_id: str, delete_documents=False) -> Dict:
         """Delete the batch with the provided batch_id, calls the DELETE /batches/{batchId} endpoint.
 
@@ -563,10 +611,10 @@ class Client:
     def list_logs(
         self,
         *,
-        workflow_id: Optional[Queryparam] = None,
-        workflow_execution_id: Optional[Queryparam] = None,
-        transition_id: Optional[Queryparam] = None,
-        transition_execution_id: Optional[Queryparam] = None,
+        workflow_id: Optional[str] = None,
+        workflow_execution_id: Optional[str] = None,
+        transition_id: Optional[str] = None,
+        transition_execution_id: Optional[str] = None,
         max_results: Optional[int] = None,
         next_token: Optional[str] = None,
     ) -> Dict:
@@ -576,14 +624,14 @@ class Client:
         >>> client = Client()
         >>> client.list_logs()
 
-        :param workflow_id:
-        :type workflow_id: Optional[Queryparam]
-        :param workflow_execution_id:
-        :type workflow_execution_id: Optional[Queryparam]
-        :param transition_id:
-        :type transition_id: Optional[Queryparam]
-        :param transition_execution_id:
-        :type transition_execution_id: Optional[Queryparam]
+        :param workflow_id: Only show logs from this workflow
+        :type workflow_id: Optional[str]
+        :param workflow_execution_id: Only show logs from this workflow execution
+        :type workflow_execution_id: Optional[str]
+        :param transition_id: Only show logs from this transition
+        :type transition_id: Optional[str]
+        :param transition_execution_id: Only show logs from this transition execution
+        :type transition_execution_id: Optional[str]
         :param max_results: Maximum number of results to be returned
         :type max_results: Optional[int]
         :param next_token: A unique token for each page, use the returned token to retrieve the next page.
@@ -623,6 +671,48 @@ class Client:
         """
         return self._make_request(requests.get, f'/logs/{log_id}')
 
+    def create_model(
+        self,
+        width: int,
+        height: int,
+        field_config: dict,
+        *,
+        preprocess_config: Optional[dict] = None,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        **optional_args,
+    ) -> Dict:
+        """Creates a model, calls the POST /models endpoint.
+
+        :param width: The number of pixels to be used for the input image width of your model
+        :type width: int
+        :param height: The number of pixels to be used for the input image height of your model
+        :type height: int
+        :param field_config: Specification of the fields that the model is going to predict
+        :type field_config: dict
+        :param preprocess_config: Specification of the processing steps prior to the prediction of an image
+        :type preprocess_config: dict
+        :param name: Name of the model
+        :type name: Optional[str]
+        :param description: Description of the model
+        :type description: Optional[str]
+        :return: Model response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        body = dictstrip({
+            'width': width,
+            'height': height,
+            'fieldConfig': field_config,
+            'preprocessConfig': preprocess_config,
+            'name': name,
+            'description': description,
+        })
+        body.update(**optional_args)
+        return self._make_request(requests.post, '/models', body=body)
+
     def list_models(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
         """List models available, calls the GET /models endpoint.
 
@@ -646,6 +736,81 @@ class Client:
         }
         return self._make_request(requests.get, '/models', params=params)
 
+    def get_model(self, model_id: str) -> Dict:
+        """Get a model, calls the GET /models/{modelId} endpoint.
+
+        :param model_id: The Id of the model
+        :type model_id: str
+        :return: Model response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.get, f'/models/{model_id}')
+
+    def update_model(
+        self,
+        model_id: str,
+        *,
+        width: Optional[int] = None,
+        height: Optional[int] = None,
+        field_config: Optional[dict] = None,
+        preprocess_config: Optional[dict] = None,
+        status: Optional[str] = None,
+        **optional_args,
+    ) -> Dict:
+        """Updates a model, calls the PATCH /models/{modelId} endpoint.
+
+        :param model_id: The Id of the model
+        :type model_id: Optional[str]
+        :param width: The number of pixels to be used for the input image width of your model
+        :type width: Optional[int]
+        :param height: The number of pixels to be used for the input image height of your model
+        :type height: Optional[int]
+        :param field_config: Specification of the fields that the model is going to predict
+        :type field_config: dict
+        :param preprocess_config: Specification of the processing steps prior to the prediction of an image
+        :type preprocess_config: dict
+        :param status: New status for the model
+        :type status: Optional[str]
+        :param name: Name of the model
+        :type name: Optional[str]
+        :param description: Description of the model
+        :type description: Optional[str]
+        :return: Model response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        body = dictstrip({
+            'width': width,
+            'height': height,
+            'fieldConfig': field_config,
+            'preprocessConfig': preprocess_config,
+            'status': status,
+        })
+        body.update(**optional_args)
+        return self._make_request(requests.patch, f'/models/{model_id}', body=body)
+
+    def delete_model(self, model_id: str) -> Dict:
+        """Delete the model with the provided model_id, calls the DELETE /models/{modelId} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.delete_model('<model_id>')
+
+        :param model_id: Id of the model
+        :type model_id: str
+        :return: Model response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        return self._make_request(requests.delete, f'/models/{model_id}')
+
     def create_prediction(
         self,
         document_id: str,
